FlutterInitials class

Constructors

FlutterInitials()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAllCases(String name) Map<String, String>
Returns a map containing all the different cases of a given name.
getInitials(String name, {int maxLength = 4}) String
Returns the initials of a given name.
getInitialsFromName(String name, {int maxLength = 4}) String
Alias for getInitials.
toCamelCase(String input) String
Converts a string to camel case.
toPascalCase(String s) String
Converts a string to Pascal case.
toSnakeCase(String s) String
Converts a string to snake case.