getAllCases static method

Map<String, String> getAllCases(
  1. String name
)

Returns a map containing all the different cases of a given name.

Returns a map with the following keys: camelCase, pascalCase, snakeCase. The values are the corresponding cases of the given name.

Implementation

static Map<String, String> getAllCases(String name) {
  Map<String, String> allCases = {};
  allCases['camelCase'] = toCamelCase(name);
  allCases['pascalCase'] = toPascalCase(name);
  allCases['snakeCase'] = toSnakeCase(name);
  return allCases;
}